# Release Notes

## 0.2.1

- Fix concat files does not have extension.

## 0.2.0

- Add all alignment features.
- Add genomic features.

## 0.1.0

- Initial release.
- Add alignment concatenation feature.
